package com.izouma.awesomeadmin.dao;

import java.util.*;
import com.izouma.awesomeadmin.datasource.DataSource;
import org.springframework.stereotype.Repository;
import com.izouma.awesomeadmin.model.TableShouyiYaopinxinxi;


/**
*  Dao接口
*/
@DataSource("dataSourceSqlserver")
@Repository("com.zoumaframe.dao.TableShouyiYaopinxinxiMapper")
public interface TableShouyiYaopinxinxiMapper{

    int deleteByPrimaryKey(Integer id);

    int insertSelective(TableShouyiYaopinxinxi record);

    TableShouyiYaopinxinxi selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(TableShouyiYaopinxinxi record);

    List<TableShouyiYaopinxinxi> queryAllTableShouyiYaopinxinxi(TableShouyiYaopinxinxi record);

    List<TableShouyiYaopinxinxi> queryTableShouyiYaopinxinxiByPage(Map<String, Object> parameter);

    int delete(String id);

    TableShouyiYaopinxinxi queryTableShouyiYaopinxinxi(TableShouyiYaopinxinxi record);

    List<TableShouyiYaopinxinxi> query(TableShouyiYaopinxinxi record);
}

